==> icons-vue-0.6.0.tgz: package/es/watson-health/window--auto/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthWindowAuto20 = {
  name: 'WatsonHealthWindowAuto20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "4"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "25",
        "y": "15"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "25"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "4",
        "y": "15"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "7.55",
        "y": "7.04",
        "transform": "rotate(-45 8.55 8.548)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "21.96",
        "y": "7.55",
        "transform": "rotate(-45 23.454 8.555)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "22.45",
        "y": "21.95",
        "transform": "rotate(-45 23.452 23.446)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "7.05",
        "y": "22.45",
        "transform": "rotate(-45 8.544 23.451)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "24",
        "height": "2",
        "x": "4",
        "y": "30"
      }
    }), createElement('rect', {
      attrs: {
        "width": "24",
        "height": "2",
        "x": "4"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,10a6,6,0,1,0,6,6A6,6,0,0,0,16,10Zm-4,6a4,4,0,0,1,4-4v8A4,4,0,0,1,12,16Z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthWindowAuto20;

==> icons-vue-10.6.1.tgz: package/es/watson-health/window--auto/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../chunk-75bb93d0.js';
import { getAttributes } from '@carbon/icon-helpers';

var virtual_WatsonHealthWindowAuto20 = {
  name: 'WatsonHealthWindowAuto20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 4h2v3h-2zm10 11h3v2h-3zM15 25h2v3h-2zM4 15h3v2H4zm2.777-6.811L8.19 6.775l2.121 2.12-1.414 1.415zm14.91.711l2.121-2.12 1.414 1.414-2.12 2.121zm-.001 14.197l1.414-1.415 2.121 2.122-1.414 1.414zM6.78 23.8l2.12-2.122 1.414 1.414-2.121 2.122zM4 30h24v2H4zM4 0h24v2H4zm12 10a6 6 0 1 0 6 6 6 6 0 0 0-6-6zm-4 6a4 4 0 0 1 4-4v8a4 4 0 0 1-4-4z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthWindowAuto20;
